@@ -1,23 +1,26 @@
-"""
-Module contains a Logger for output logs into the console and/or to Azure over the app insights sdk. 
+""" Steineman DPE logger
+    Authors: Joshoua Bigler
+
+    Description
+    -----------
+    Module contains a Logger for output logs into the console and/or to Azure over the app insights sdk. 
 """
 
 import datetime
 import logging
-
 from opencensus.ext.azure.log_exporter import AzureLogHandler
 
 
 class Logger():
-  """Class to handle the console and the Azure (app insights sdk) logging output.
+  """ Class to handle the console and the Azure (app insights sdk) logging output.
 
-  Log level meanings
-  ------------------
-  DEBUG:    Detailed information
-  INFO:     Confirmation that things are working as expected
-  WARNING:  Warnings
-  ERROR:    Serious problem
-  CRITICAL: A serious error
+      Log level meanings
+      ------------------
+      DEBUG:    Detailed information
+      INFO:     Confirmation that things are working as expected
+      WARNING:  Warnings
+      ERROR:    Serious problem
+      CRITICAL: A serious error
   """
   # class variables
   logger = None
